require 'rails_helper'

RSpec.describe Integrator::Devise::RegistrationsController, type: :controller do
  before { @request.env['devise.mapping'] = Devise.mappings[:integrator_user] }
  routes { Integrator::Engine.routes }

  describe 'GET /signup' do
    def request(_attr = {})
      get :new
    end

    it_behaves_like 'success response'

    context 'if CMS already has at least one user' do
      before { create :user }

      it 'redirect to login path' do
        expect(request).to redirect_to login_path
      end
    end

    context 'if CMS has not user' do
      it 'render new template' do
        expect(request).to render_template :new
      end
    end
  end


  describe 'POST /signup' do
    context 'if CMS already has at least one user' do
      before { create :user }
      def request
        post :create, params: { integrator_user: { email: 'admin2@belweb.pro', password: 'P@ssw0rd' } }
      end

      it 'redirect to login path' do
        expect(request).to redirect_to login_path
      end
    end

    context 'if CMS has not user' do
      context 'with valid attributes' do
        def request
          post :create, params: { integrator_user: { email: 'admin@belweb.pro', password: 'P@ssw0rd' } }
        end

        it_behaves_like 'createable with valid params', model: Integrator::User

        it 'redirect to dashboard (root path)' do
          expect(request).to redirect_to root_path
        end
      end

      context 'with invalid attributes' do
        def request
          post :create, params: { integrator_user: { email: 'admin@belweb.pro', password: '1234567' } }
        end

        it_behaves_like 'success response'
        it_behaves_like 'not createable with invalid params', model: Integrator::User

        it 'render new template' do
          expect(request).to render_template :new
        end
      end
    end
  end
end
