require 'rails_helper'

RSpec.describe Integrator::Devise::SessionsController, type: :controller do
  before { @request.env['devise.mapping'] = Devise.mappings[:integrator_user] }
  routes { Integrator::Engine.routes }

  describe 'GET /login' do
    def request(_attr = {})
      get :new
    end

    context 'if CMS has not user' do
      it 'redirect to signup path' do
        expect(request).to redirect_to signup_path
      end
    end

    context 'if CMS already has at least one user' do
      before { create :user }

      it_behaves_like 'success response'

      it 'render new template' do
        expect(request).to render_template :new
      end
    end
  end


  describe 'POST /login' do
    context 'if CMS already has at least one user' do
      before { create :user, email: 'user@belweb.pro', password: 'P@ssw0rd' }

      context 'with valid login params' do
        def request
          post :create, params: { integrator_user: { email: 'user@belweb.pro', password: 'P@ssw0rd' } }
        end

        it 'redirect to dashboard (root path)' do
          expect(request).to redirect_to root_path
        end
      end

      # todo ??? stack level too deep (not proxy in warden) ???
      # context 'with invalid login params' do
      #   def request
      #     post :create, params: { integrator_user: { email: 'user2@belweb.pro', password: 'P@ssw0rd' } }
      #   end
      #   it_behaves_like 'need authorized'
      #
      #   it 'render new template' do
      #     request
      #     expect(response).to render_template :new
      #   end
      # end
    end

    context 'if CMS has not user' do
      def request
        post :create, params: { integrator_user: { email: 'admin@belweb.pro', password: 'P@ssw0rd' } }
      end

      it 'redirect to signup path' do
        expect(request).to redirect_to signup_path
      end
    end
  end
end
