require 'rails_helper'

feature 'First admin can sign up', %q{
  In order to start work with iCMS
  As an first admin
  I want to be able sign up
} do

  describe 'Admin can sign up' do
    scenario 'with valid registered data' do
      visit root_path
      expect(page).to have_content I18n.t('devise.registrations.sign_up_welcome')

      fill_in 'integrator_user[email]', with: 'admin@belweb.pro'
      fill_in 'integrator_user[password]', with: 'P@ssw0rd'
      fill_in 'integrator_user[password_confirmation]', with: 'P@ssw0rd'
      click_button I18n.t('devise.registrations.sign_up_button')

      expect(page).to have_content I18n.t('devise.registrations.signed_up')
    end
  end


  describe 'Admin can not sign up' do
    scenario 'with invalid registered data' do
      visit root_path
      expect(page).to have_content I18n.t('devise.registrations.sign_up_welcome')

      fill_in 'integrator_user[email]', with: 'admin@yandex.ru'
      fill_in 'integrator_user[password]', with: '1234567'
      fill_in 'integrator_user[password_confirmation]', with: '1234567'
      click_button I18n.t('devise.registrations.sign_up_button')

      expect(page).to have_content "Password #{I18n.t('activerecord.errors.models.integrator/user.attributes.password.too_short')}"
    end
  end


  describe 'Nobody can sign up' do
    given!(:user) { create(:user) }

    scenario 'when exist at least one user' do
      visit integrator.signup_path
      expect(current_path).to eq integrator.login_path
    end
  end
end
